from enum import Enum

class Sql_Status(Enum):
    unconnected: int
    disconnected: int
    connected: int

class Isolation_Status(Enum):
    read_uncommitted: int
    read_committed: int
    repeatable_read: int
    serializable: int

class Commit_Status(Enum):
    manual_commit: int
    auto_commit: int



from _typeshed import Incomplete
from enum import Enum
from typing import Any, Callable, Iterator, List, Union

class ThreadPoolStatus(Enum):
    unstarted: int
    running: int
    finished: int
    terminated: int

class n_ThreadPool:
    max_workers: Incomplete
    daemon: Incomplete
    status: Incomplete
    task_count: int
    task_finished_count: int
    task_unfinished_count: int
    def __init__(self, max_workers: int = ..., daemon: bool = ...) -> None: ...
    def setGroupExecInterval(self, group: int, time_interval: float): ...
    def put(self, func: Callable, *args, **kwargs): ...
    def start(self) -> None: ...
    def startAndWait(self) -> List[Any]: ...
    def map(self, func: Callable, *iterables, timeout: Union[float, None] = ...) -> Iterator: ...
    def clear(self) -> None: ...
    def stopAnyWay(self) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type, exc_val, exc_tb): ...
